searchData={"items":[{"type":"module","doc":"Utilities for verifing an HTTP request can be authenticated as a request\ncoming from Slack HQ.\n\nhttps://api.slack.com/authentication/verifying-requests-from-slack","title":"SlackRequest","ref":"SlackRequest.html"},{"type":"function","doc":"","title":"SlackRequest.signature/1","ref":"SlackRequest.html#signature/1"},{"type":"function","doc":"","title":"SlackRequest.timestamp/1","ref":"SlackRequest.html#timestamp/1"},{"type":"function","doc":"","title":"SlackRequest.valid_signature?/2","ref":"SlackRequest.html#valid_signature?/2"},{"type":"function","doc":"","title":"SlackRequest.valid_timestamp?/1","ref":"SlackRequest.html#valid_timestamp?/1"},{"type":"module","doc":"Intended to be used as the [`:body_reader`](`Plug.Parsers#module-options`) option of `Plug.Parsers`.\n\nKeeps the raw body in a private conn assign so that it can be used later in the call stack\nfor verification of the Slack HQ HTTP request timestamp and signtaure.\n\nNote that default `Plug.Conn.read_body/2` reads the body once but doesn't keep it for later further\ninspection.","title":"SlackRequest.BodyReader","ref":"SlackRequest.BodyReader.html"},{"type":"module","doc":"```elixir\n# endpoint.ex\nPlug.Parsers,\n  ...\n  body_reader: {SlackRequest.BodyReader, :read_and_cache_body, []}\n```\n\nSo later, one can get the cached body with:\n\n```elixir\nSlackRequest.BodyReader.cached_body(conn)\n```","title":"Example - SlackRequest.BodyReader","ref":"SlackRequest.BodyReader.html#module-example"},{"type":"function","doc":"","title":"SlackRequest.BodyReader.cached_body/1","ref":"SlackRequest.BodyReader.html#cached_body/1"},{"type":"function","doc":"","title":"SlackRequest.BodyReader.get_raw_body/1","ref":"SlackRequest.BodyReader.html#get_raw_body/1"},{"type":"function","doc":"","title":"SlackRequest.BodyReader.read_and_cache_body/2","ref":"SlackRequest.BodyReader.html#read_and_cache_body/2"},{"type":"function","doc":"","title":"SlackRequest.BodyReader.read_body/2","ref":"SlackRequest.BodyReader.html#read_body/2"},{"type":"module","doc":"Plug that automatically tries to verify timestamp and signature of the HTTP request\nto check is a valid Slack HQ HTTP request.\n\nIt needs `SlackRequest.BodyReader.read_and_cache_body/2` to be set as the `Plug.Parsers`\n[`:body_reader`](`Plug.Parsers#module-options`).","title":"SlackRequest.Plug","ref":"SlackRequest.Plug.html"},{"type":"function","doc":"","title":"SlackRequest.Plug.call/2","ref":"SlackRequest.Plug.html#call/2"},{"type":"function","doc":"","title":"SlackRequest.Plug.init/1","ref":"SlackRequest.Plug.html#init/1"},{"type":"extras","doc":"# 🔐 SlackRequest\n\nUtilities for verifing an HTTP request can be authenticated as a request\ncoming from Slack HQ.\n\nhttps://api.slack.com/authentication/verifying-requests-from-slack","title":"🔐 SlackRequest","ref":"readme.html"},{"type":"extras","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `slack_request` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:slack_request, \"~> 0.3.1\"}\n  ]\nend\n```","title":"Installation - 🔐 SlackRequest","ref":"readme.html#installation"},{"type":"extras","doc":"","title":"Usage - 🔐 SlackRequest","ref":"readme.html#usage"},{"type":"extras","doc":"Set `body_reader:` in `Plug.Parsers` inside your `Endpoint`.\n\n```elixir\n# lib/your_app_web/endpoint.ex\n\ndefmodule YourAppWeb.Endpoint do\n  ...\n\n  plug Plug.Parsers,\n    ...\n    body_reader: {SlackRequest.BodyReader, :read_and_cache_body, []}\nend\n```\n\nPlug the `SlackRequest.Plug` in the pipeline that handles your Slack Requests/Webhooks.\n\nExample:\n\n```elixir\n# lib/your_app_web/router.ex\n\ndefmodule YourAppWeb.Router do\n\n  ...\n\n  pipeline :slack do\n    plug :accepts, [\"json\"]\n    plug SlackRequest.Plug\n  end\n\n  scope \"/slack\", YourAppWeb do\n    pipe_through :slack\n\n    ...\n  end\n```","title":"Plug - 🔐 SlackRequest","ref":"readme.html#plug"},{"type":"extras","doc":"Or if just prefer to use the validation function directly:\n\n```elixir\n# Somewhere were you're ready to validate the incoming request conn\n\nif SlackRequest.valid_signature?(conn, secret: signing_secret, body: raw_request_body) do\n  # all good\nelse\n  # handle invalid slack request/webhook\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","title":"Manual - 🔐 SlackRequest","ref":"readme.html#manual"},{"type":"extras","doc":"Copyright 2024 Mimiquate\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","title":"License - 🔐 SlackRequest","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}